"use strict";
/********************************************************************************
 * Copyright (c) 2022 Anibal Solon and others
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0 which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * SPDX-License-Identifier: EPL-2.0
 ********************************************************************************/
Object.defineProperty(exports, "__esModule", { value: true });
exports.verifyPat = verifyPat;
exports.doVerifyPat = doVerifyPat;
const registry_1 = require("./registry");
const util_1 = require("./util");
/**
 * Validates that a Personal Access Token can publish to a namespace.
 */
async function verifyPat(options) {
    (0, util_1.addEnvOptions)(options);
    if (!options.namespace) {
        let error;
        try {
            options.namespace = (await (0, util_1.readManifest)()).publisher;
        }
        catch (e) {
            error = e;
        }
        if (!options.namespace) {
            throw new Error(`Unable to read the namespace's name. Please supply it as an argument or run ovsx from the extension folder.` +
                (error ? `\n\n${error}` : ''));
        }
    }
    options.pat = await (0, util_1.getPAT)(options.namespace, options, false);
    await doVerifyPat(options);
}
async function doVerifyPat(options) {
    const registry = new registry_1.Registry(options);
    const namespace = options.namespace;
    const pat = options.pat;
    const result = await registry.verifyPat(namespace, pat);
    if (result.error) {
        throw new Error(result.error);
    }
    console.log(`\ud83d\ude80  PAT valid to publish at ${namespace}`);
}
//# sourceMappingURL=verify-pat.js.map