"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.readZip = readZip;
exports.readVSIXPackage = readVSIXPackage;
const yauzl_1 = require("yauzl");
async function bufferStream(stream) {
    return await new Promise((resolve, reject) => {
        const buffers = [];
        stream.on('data', buffer => buffers.push(buffer));
        stream.once('error', reject);
        stream.once('end', () => resolve(Buffer.concat(buffers)));
    });
}
async function readZip(packagePath, filter) {
    const zipfile = await new Promise((resolve, reject) => (0, yauzl_1.open)(packagePath, { lazyEntries: true }, (err, zipfile) => (err ? reject(err) : resolve(zipfile))));
    return await new Promise((resolve, reject) => {
        const result = new Map();
        zipfile.once('close', () => resolve(result));
        zipfile.readEntry();
        zipfile.on('entry', (entry) => {
            const name = entry.fileName.toLowerCase();
            if (filter(name)) {
                zipfile.openReadStream(entry, (err, stream) => {
                    if (err) {
                        zipfile.close();
                        return reject(err);
                    }
                    bufferStream(stream).then(buffer => {
                        result.set(name, buffer);
                        zipfile.readEntry();
                    });
                });
            }
            else {
                zipfile.readEntry();
            }
        });
    });
}
async function readVSIXPackage(packagePath) {
    const map = await readZip(packagePath, name => /^extension\/package\.json$/i.test(name));
    const rawManifest = map.get('extension/package.json');
    if (!rawManifest) {
        throw new Error('Manifest not found.');
    }
    return JSON.parse(rawManifest.toString('utf8'));
}
//# sourceMappingURL=zip.js.map